==> github-widget2-1.0.0.tgz: package/lib/test/issues.test.js <==
'use strict';

var _jsxFileName = '../../src/test/issues.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Issues = require('../components/Issues/Issues');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        issues: {
          issuesById: {
            246869449: {
              assignedTo: [],
              labels: [],
              repoIssueNumber: 36,
              title: 'disregard this PR'

            }
          }
        },
        loadingIssues: false,
        currentPage: { selectedOrgName: 'ski-ski', userName: 'michaelmurray6298' }
      }
    }
  }
  // loadingIssues: false,
  // currentPage: { selectedOrgName: 'ski-ski', userName: 'michaelmurray6298' },
};

describe('Issues component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveIssues = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issues.Issues, {
      issuesIds: state.widgets.byId.github.issues.ids,
      loadingIssues: false,
      retrieveIssues: retrieveIssues,
      orgName: state.widgets.byId.github.currentPage.selectedOrgName,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 34
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      issuesByRepo: undefined,
      loadingIssues: false,
      orgName: 'ski-ski',
      userName: 'michaelmurray6298'
    };
    expect((0, _Issues.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Issues.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveIssues');
  });

  it('Should have a Cart Header in the center', function () {
    var retrieveIssues = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issues.Issues, {
      issuesIds: state.widgets.byId.github.issues.ids,
      loadingIssues: false,
      retrieveIssues: retrieveIssues,
      orgName: state.widgets.byId.github.currentPage.selectedOrgName,
      userName: state.widgets.byId.github.currentPage.userName,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 62
      },
      __self: undefined
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/issues.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Issues = require('../components/Issues/Issues');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        issues: {
          issuesById: {
            246869449: {
              assignedTo: [],
              labels: [],
              repoIssueNumber: 36,
              title: 'disregard this PR'

            }
          }
        },
        loadingIssues: false,
        currentPage: { selectedOrgName: 'ski-ski', userName: 'michaelmurray6298' }
      }
    }
  }
  // loadingIssues: false,
  // currentPage: { selectedOrgName: 'ski-ski', userName: 'michaelmurray6298' },
};

describe('Issues component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveIssues = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issues.Issues, {
      issuesIds: state.widgets.byId.github.issues.ids,
      loadingIssues: false,
      retrieveIssues: retrieveIssues,
      orgName: state.widgets.byId.github.currentPage.selectedOrgName
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      issuesByRepo: undefined,
      loadingIssues: false,
      orgName: 'ski-ski',
      userName: 'michaelmurray6298'
    };
    expect((0, _Issues.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Issues.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveIssues');
  });

  it('Should have a Cart Header in the center', function () {
    var retrieveIssues = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issues.Issues, {
      issuesIds: state.widgets.byId.github.issues.ids,
      loadingIssues: false,
      retrieveIssues: retrieveIssues,
      orgName: state.widgets.byId.github.currentPage.selectedOrgName,
      userName: state.widgets.byId.github.currentPage.userName
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});
